<?php
//
// SLA Config Wizard
// Copyright (c) 2015 Nagios Enterprises, LLC. All rights reserved.
//

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// Run the initialization function
sla_configwizard_init();

function sla_configwizard_init()
{
    $name="sla";

    $args=array(
        CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.0.1",
        CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
        CONFIGWIZARD_DESCRIPTION => _("Monitor Service Level Agreements (SLA) to ensure they are met."),
        CONFIGWIZARD_DISPLAYTITLE => _("SLA"),
        CONFIGWIZARD_FUNCTION => "sla_configwizard_func",
        CONFIGWIZARD_PREVIEWIMAGE => "sla.png",
        CONFIGWIZARD_FILTER_GROUPS => array('nagios'),
        CONFIGWIZARD_REQUIRES_VERSION => 500
        );

    register_configwizard($name,$args);
}

/**
 * @return array
 */
function sla_configwizard_check_prereqs()
{
    $errors = array();

    if(!file_exists("/usr/local/nagios/libexec/check_xisla.php")){
        $errors[] = _('It looks like you are missing check_xisla.php on your Nagios XI server. To use this wizard you must install the check_xisla.php plugin on your server located in the this wizards plugin directory.  Move here: /usr/local/nagios/libexec/');
    }

    return $errors;
}

/**
 * @param string $mode
 * @param null   $inargs
 * @param        $outargs
 * @param        $result
 *
 * @return string
 */
function sla_configwizard_func($mode="",$inargs=null,&$outargs,&$result)
{
    $wizard_name="sla";
    
    // initialize return code and output
    $result=0;
    $output="";

    // initialize output args - pass back the same data we got
    $outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;

    switch($mode){
        case CONFIGWIZARD_MODE_GETSTAGE1HTML:
            $address = grab_array_var($inargs, "address", "localhost");
            $username = grab_array_var($inargs, "username", "");
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $remote = grab_array_var($inargs, "remote", 0);

            $errors = sla_configwizard_check_prereqs();

            // get list of users from the backend
            $args = array(
                "cmd" => "getusers",
            );

            $xmlusers = get_backend_xml_data($args);

            if($errors) {
                $output.='<div class="message"><ul class="errorMessage">';
                foreach($errors as $error) {
                    $output.="<li><p>$error</p></li>";
                }
                $output.='</ul></div>';
            } else {

                $services=grab_array_var($inargs,"services",array());
                $serviceargs=grab_array_var($inargs,"serviceargs",array());

                $output='

    <input type="hidden" name="address" value="' . $address . '">
    <input type="hidden" name="username" value="' . $username . '">
    <input type="hidden" name="auth_file" value="' . $auth_file . '">
    <input type="hidden" name="remote" value="' . $remote . '">

<h5 class="ul">' . _('Nagios XI ') . '</h5>
    <p>' . _('Fill in the credentials for the Nagios XI server that will be running the SLA query. By default the SLA wizard will run locally') . '.</p>

    <input id="remotecheck" class="btn btn-sm btn-primary" value="Remote Host" style="width: 100px;margin-right: 5px;">' . _('This toggles local and remote wizard options.') . '<br><br>

    <table class="table table-condensed table-no-border table-auto-width">
        <tbody id="localbody" style="display:block;">
            <tr>
                <td class="vt">
                    <label>' . _("Nagios XI Host") . ':&nbsp;&nbsp;</label>
                </td>
                <td>
                    <input type="text" size="25" name="address" id="address" value="localhost" class="form-control" disabled/>
                </td>
            </tr>
            <tr>
                <td class="vt">
                    <label>' . _('Nagios XI User') . ':</label>
                </td>
                <td class="vt">
                    <select name="username" style="width:175px" class="form-control">
                        <option value="">' . _('Select User') . '</option>
                        ';
                        if ($xmlusers) {

                            foreach ($xmlusers->user as $u) {
                                // print_r($u);

                                $uid = get_user_id($u->username);

                                $output .= "<option id='username' value='" . $u->username . "' " . is_selected($username, strval($u->username)) . ">" . $u->name . " (" . $u->username . ")</option>\n";
                            }
                        } else {  // if not-admin set as session user
                                $output .= "<option id='username' value='" . $_SESSION['username'] . "' " . is_selected($username, strval($u->username)) . ">" . $_SESSION['username'] . "</option>\n";
                        }

                        $output .= '
                    </select>
                    <div class="subtext">' . _("Select a user to run this wizard with") . '.</div>
                </td>
            </tr>
        </tbody>
        <tbody id="remotebody" style="display:none;border:none;">
            <tr>
                <td class="vt">
                    <label>' . _("Nagios XI Host") . ':</label>
                </td>
                <td>
                    <input type="text" size="25" name="address" id="address" value="' . htmlentities($address) . '" class="form-control" />
                    <div class="subtext">' . _("The FQDN of the host the wizard will query the SLA data from") . '.</div>
                </td>
            </tr>
            <tr>
                <td class="vt">
                    <label>' . _('Auth File:') . '</label>
                </td>
                <td>
                    <input type="text" size="50" name="auth_file" id="auth_file" value="' . htmlentities($auth_file) . '" class="form-control">
                    <div class="subtext">' . _('File to use with Nagios XI username and ticket for authencation.') . '</div>
                </td>
            </tr>
        </tbody>
    </table>

    <script>
        $(document).ready(function() {
            var remote_div = $("input[name=remote]");
            var name = "";
            name = $("#remotecheck");

            if (remote_div.val() == 1) {
                name.val("Remote Host");
                remote_div.val("1");
                $("#localbody").hide();
                $("#remotebody").show();
            } else {
                $("#auth_file").val("");
                name.val("Local Host");
                remote_div.val("0");
                $("#localbody").show();
                $("#remotebody").hide();
            }

            $("#remotecheck").click(function(index) {
                if (name.val() !== "Remote Host") {
                    name.val("Remote Host");
                    remote_div.val("1");
                } else {
                    name.val("Local Host");
                    remote_div.val("0");
                    $("#auth_file").val("");
                }

                $("#localbody").toggle();
                $("#remotebody").toggle();
            });
        });
    </script>
        ';
        }
            break;

        case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:

            // get variables that were passed to us
            $address = grab_array_var($inargs, "address", "");
            $username = grab_array_var($inargs, "username", "");
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $services_serial=grab_array_var($inargs,"services_serial");
            $serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
            $remote = grab_array_var($inargs, "remote");

            // check for errors
            $errors = 0;
            $errmsg = array();

            if (!$remote) {
                if (!empty($username) == false)
                    $errmsg[$errors++] = _("No Nagios XI Username specified.  Select one from the dropdown.");
            }

            if ($remote) {
                if (!empty($auth_file) == false)
                    $errmsg[$errors++] = _("No Nagios XI SLA Authentication file has been specified.");

                // Verify then write auth file contents
                $auth_test = file_get_contents($auth_file);
                if ($auth_test === false) {
                    $errmsg[$errors++] = _("The Authentication file does not exist, could not be read or is not formatted correctly.");
                }
            }

            if ($errors>0) {
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
            }

            break;

        case CONFIGWIZARD_MODE_GETSTAGE2HTML:

            // get variables that were passed to us
            $address = grab_array_var($inargs, "address", "");
            $ha = @gethostbyaddr($address);
            $username = grab_array_var($inargs, "username", "");
            $hostname = grab_array_var($inargs, "hostname", $ha ? $ha : $address);
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $remote = grab_array_var($inargs, "remote", "");

            // Verify then write auth file contents if we are using an auth file
            if ($remote && !empty($auth_creds)) {
                $auth_creds = file_get_contents($auth_file);
                $auth_creds = explode("\n", $auth_creds);
                $username = split("=", $auth_creds[0]);
                $username = $username[1];
            } else if (!$remote) {
                // Set API ticket if on localhost
                if ($username != "") {
                    $uid = get_user_id($username);

                    if ($uid == 0 || $uid == null)
                        $ticket = "";
                    else
                        $ticket = get_user_attr($uid, "backend_ticket");
                }
            }

            $warning = grab_array_var($inargs, "warning");
            $critical = grab_array_var($inargs, "critical");

            // If no serialized data, use current request data if available.
            $services = "";
            $services_serial = grab_array_var($inargs, "services_serial", "");
            if (!empty($services_serial))
                $services = unserialize(base64_decode($services_serial));
            
            if (!is_array($services)) {
                // Initialize service array variables
                $services_default = grab_array_var($inargs, "services", array(
                    "host" => array(),
                    "service" => array(),
                    "hostgroup" => array(),
                    "servicegroup" => array()
                ));

                $services = grab_array_var($inargs, "services", $services_default);
                $services_serial = base64_encode(serialize($services));
            }

            $serviceargs = "";
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial", "");
            if (!empty($serviceargs_serial)) 
                $serviceargs = unserialize(base64_decode($serviceargs_serial));

            if (!is_array($serviceargs)) {
                $serviceargs_default = grab_array_var($inargs, "serviceargs", array(
                    "username"=>$username,
                    "auth_file"=>$auth_file,
                    "advanced"=>array(
                        "mode"=>0,
                        "assumeinitials"=>"yes",
                        "assumestater"=>"yes",
                        "assumedown"=>"yes",
                        "softstate"=>"no",
                        "asssumehs"=>3,
                        "asssumess"=>6,
                        "manual_run"=>1,
                        "reportperiod"=>"last24hours",
                        "dont_count_downtime"=>0,
                        "dont_count_warning"=>0,
                        "dont_count_unknown"=>0
                    )
                ));
                $serviceargs = grab_array_var($inargs, "serviceargs", $serviceargs_default);

                foreach ($services as $svc => $val) {
                    for ($x = 0; $x < 2; $x++) {
                        if (!array_key_exists($x, $services))
                            $services[$svc][$x] = '';
                        if (!array_key_exists($x, $services)) {
                            $serviceargs[$svc][$x] = array(
                                $svc => $svc,
                                "username"=>$username,
                                "ticket"=>$ticket,
                                "warning"=>"",
                                "critical"=>""
                            );
                        }
                    }
                }

                $serviceargs_serial = base64_encode(serialize($serviceargs));
            }

            foreach ($services as $svc => $val) {
                for ($x = 0; $x < 2; $x++) {
                    if (!array_key_exists($x, $services))
                        $services[$svc][$x] = '';

                    if (!array_key_exists($x, $services)) {
                        $serviceargs[$svc][$x] = array(
                            $svc => $svc,
                            "username"=>$username,
                            "ticket"=>$ticket,
                            "warning"=>"",
                            "critical"=>""
                        );
                    }
                }
            }

            $output = '

        <input type="hidden" name="address" value="' . htmlentities($address) . '" />
        <input type="hidden" name="hostname" value="' . htmlentities($hostname) . '" />
        <input type="hidden" name="username" value="' . $username . '" />
        <input type="hidden" name="auth_file" value="' . $auth_file . '" />
        <input type="hidden" name="warning" value="' . $warning . '" />
        <input type="hidden" name="critical" value="' . $critical . '" />
        <input type="hidden" name="services_serial" value="' . $services_serial . '" />
        <input type="hidden" name="serviceargs_serial" value="' . $serviceargs_serial . '" />
        <input type="hidden" name="remote" value="' . $remote . '">
    
    <h5 class="ul">' . _('Nagios XI Settings') . '</h5>
    <p>'._('These are the settings used to connect to the Nagios XI server where the SLA report will be run').'.</p>

    <table class="table table-condensed table-no-border table-auto-width">
        <tr>
            <td class="vt">
                <label>' . _("Nagios XI Host") . ':</label>
            </td>
            <td>
                <input type="text" size="20" name="address" id="address" value="' . htmlentities($address) . '" class="form-control" disabled>
                <div class="subtext">' . _("The FQDN of the Nagios XI host the wizard will query the SLA data from") . '.</div>
            </td>
        </tr>
        <tr>
            <td class="vt">
                <label>' . _('Nagios XI User') . ':</label>
            </td>
            <td>
                <input type="text" size="20" name="username" id="username" value="' . htmlentities($username) . '" class="form-control" />
                <div class="subtext">' . _("The User account associated with the Nagios XI server") . '.</div>
            </td>
        </tr>
        <tr>';

        // if remote show auth file input, otherwise show XI ticket input
        if ($remote) {
            $output .= '
                <td class="vt">
                    <label>' . _('Auth File') . ':</label>
                </td>
                <td>
                    <input type="text" size="30" name="auth_file" id="auth_file" value="' . $auth_file . '" class="form-control">
                    <div class="subtext">' . _("File to use with Nagios XI username and ticket for authencation.") . '</div>
                </td>';
        } else {
            $output .= '
                <td class="vt">
                    <label>' . _('XI Ticket') . ':</label>
                </td>
                <td>
                    <input type="password" size="20" name="ticket" id="ticket" value="' . $ticket . '" class="form-control">
                    <div class="subtext">' . _("Automatically assigned API key for the user that was selected.") . '</div>
                </td>';
        }

        $output .= '
        </tr>
    </table>

    <div style="height: 10px;"></div>

    <h5 class="ul">' . _('SLA Report Advanced Settings') . '</h5>
    <p>' . _('These are settings used to manipulate the way SLA data is reported and received. These settings will apply to all services in the wizard') . '.</p>

    <table class="table table-condensed table-no-border table-auto-width">
        <tr>
            <td>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("Assume Initial States") . '
                    <select name="assumeinitials" class="form-control">
                        <option value="yes" ';
                            if ($serviceargs['advanced']['assumeinitials'] == "yes") { $output .= "selected"; }
                            $output .= '>' . _("Yes") . '</option>
                        <option value="no"'; 
                            if ($serviceargs['advanced']['assumeinitials'] == "no") {  $output .= "selected"; } 
                            $output .= '>' .  _("No") . '</option>
                    </select>
                </div>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("Assume State Retention") . '
                    <select name="assumestater" class="form-control">
                        <option value="yes"';
                            if ($serviceargs['advanced']['assumestater'] == "yes") { $output .= "selected"; }
                            $output .= '>' . _("Yes") . ' </option>
                        <option value="no"';
                            if ($serviceargs['advanced']['assumestater'] == "no") { $output .= "selected"; }
                            $output .= '>' . _("No") . ' </option>
                    </select>
                </div>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("Assume States During Program Downtime") . '
                    <select name="assumedown" class="form-control">
                        <option value="yes"';
                            if ($serviceargs['advanced']['assumedown'] == "yes") { $output .= "selected"; }
                            $output .= '>' . _("Yes") . ' </option>
                        <option value="no"';
                            if ($serviceargs['advanced']['assumedown'] == "no") { $output .= "selected"; }
                            $output .= '>' . _("No") . ' </option>
                    </select>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("Include Soft States") . '
                    <select name="softstate" class="form-control">
                        <option value="no"';
                            if ($serviceargs['advanced']['softstate'] == "no") { $output .= "selected"; }
                            $output .= '>' . _("No") . ' </option>
                        <option value="yes"';
                            if ($serviceargs['advanced']['softstate'] == "yes") { $output .= "selected"; }
                            $output .= '>' . _("Yes") . ' </option>
                    </select>
                </div>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("First Assumed Host State") . '
                    <select name="asssumehs" class="form-control">
                        <option value="0"';
                            if ($serviceargs['advanced']['asssumehs'] == 0) { $output .= "selected"; }
                            $output .= '>' . _("Unspecified") . ' </option>
                        <option value="-1"';
                            if ($serviceargs['advanced']['asssumehs'] == -1) { $output .= "selected"; }
                            $output .= '>' . _("Current State") . ' </option>
                        <option value="3"';
                            if ($serviceargs['advanced']['asssumehs'] == 3) { $output .= "selected"; }
                            $output .= '>' . _("Host Up") . ' </option>
                        <option value="4"';
                            if ($serviceargs['advanced']['asssumehs'] == 4) { $output .= "selected"; }
                            $output .= '>' . _("Host Down") . ' </option>
                        <option value="5"';
                            if ($serviceargs['advanced']['asssumehs'] == 5) { $output .= "selected"; }
                            $output .= '>' . _("Host Unreachable") . ' </option>
                    </select>
                </div>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("First Assumed Service State") . '
                    <select name="asssumess" class="form-control">
                        <option value="0"';
                            if ($serviceargs['advanced']['asssumess'] == 0) { $output .= "selected"; }
                            $output .= '>' . _("Unspecified") . ' </option>
                        <option value="-1"';
                            if ($serviceargs['advanced']['asssumess'] == -1) { $output .= "selected"; }
                            $output .= '>' . _("Current State") . ' </option>
                        <option value="6"';
                            if ($serviceargs['advanced']['asssumess'] == 6) { $output .= "selected"; }
                            $output .= '>' . _("Service Ok") . ' </option>
                        <option value="7"';
                            if ($serviceargs['advanced']['asssumess'] == 7) { $output .= "selected"; }
                            $output .= '>' . _("Service Warning") . ' </option>
                        <option value="8"';
                            if ($serviceargs['advanced']['asssumess'] == 8) { $output .= "selected"; }
                            $output .= '>' . _("Service Unknown") . ' </option>
                        <option value="9"';
                            if ($serviceargs['advanced']['asssumess'] == 9) { $output .= "selected"; }
                            $output .= '>' . _("Service Critical") . ' </option>
                    </select>
                </div>
            </td>
        </tr>
        <tr>
            <td>
                <div style="float: left; margin-right: 10px; padding-bottom: 10px;">
                    ' . _("Report Time Period") . '
                    <select name="reportperiod" class="form-control" style="width: 150px;">
                        <option value="" ';
                            if ($serviceargs['advanced']['reportperiod'] == "") { $output .= "selected"; }
                            $output .= '>' . _("None") . ' </option>';
                        // Get a list of reportperiods
                        $request = array("objecttype_id" => 9);
                        $objects = new SimpleXMLElement(get_objects_xml_output($request));
                        foreach ($objects as $object) {
                            $tp = (string)$object->name1;
                            if (!empty($tp)) {
                                $output .= "<option " . is_selected($serviceargs['advanced']['reportperiod'], $tp) . ">" . $tp . "</option>";
                            }
                        }
                        $output .= '
                    </select>
                </div>
                <div style="float: left; margin: 2px 4px 2px 10px;">
                    <label title="' . _('This will count any state during scheduled downtime as OK for the SLA report') . '">
                        <input type="checkbox" name="dont_count_downtime" style="margin: 4px;" ';
                            if ($serviceargs['advanced']['dont_count_downtime'] == 1) { $output .= "checked";  }
                            $output .= '>' . _("Hide scheduled downtime") . '
                    </label>
                </div>
                <div style="float: left; margin: 2px 4px 2px 10px;">
                    <label title="' . _('This will count any WARNING state as OK for the SLA report') . '">
                        <input type="checkbox" name="dont_count_warning" style="margin: 4px;" ';
                        if ($serviceargs['advanced']['dont_count_warning'] == 1) { $output .= "checked";  }
                        $output .= '>' . _("Hide Warning states") . '
                    </label>
                </div>
                <div style="float: left; margin: 2px 4px 2px 10px;">
                    <label title="' . _('This will count any UNKNOWN state as OK for the SLA report') . '">
                        <input type="checkbox" name="dont_count_unknown" style="margin: 4px;" ';
                        if ($serviceargs['advanced']['dont_count_unknown'] == 1) { $output .= "checked";  }
                        $output .= '>' . _("Hide Unknown/Unreachable states") . '
                    </label>
                </div>
            </td>
        </tr>
    </table>

<script>
    $(document).ready(function() {
        $("#tabs").tabs();

        var servicetarget = "";

        $(".adddeleterow").on("change", ".hostSList", function () {
            if ($(this).val() != "") {
                servicetarget = $(this).parents("tr").find(".serviceList");
                update_service_list($(this).val(), servicetarget);
            }
        });

        function update_service_list(host, servicetarget) {
            $.get("/nagiosxi/reports/sla.php?mode=getservices&host=" + host, function(data) {
                servicetarget.html(data);
            });
        }
    });
</script>

    <input type="hidden" name="address" id="address" value="' . $address . '">

<h5 class="ul">' . _('Check SLA Setup') . '</h5>
    <div class="message" style="max-width:700px;"><ul class="actionMessage">' . _("Warning and Critical for the SLA wizard support targeted and ranged thresholds following the Nagios Plugins guidelines ") . '<a target="_blank" href="https://nagios-plugins.org/doc/guidelines.html#THRESHOLDFORMAT">here</a>.<br><br>' . _("Normally when using warning and critical values to alert warning must be lower than critical, but for SLA the higher the percentage ") . '<br>' . _("the better.  Because of this the wizard will automatically add a '@' in front of the warning and critical values to reverse them.") . '</ul>
    </div>

<div id="tabs" style="max-width:700px;">
    <ul>
        <li><a href="#host" id="selecthost">Host</a></li>
        <li><a href="#service" id="selectservice">Service</a></li>
        <li><a href="#hostgroup" id="selecthostgroup">Hostgroup</a></li>
        <li><a href="#servicegroup" id="selectservicegroup">Servicegroup</a></li>
    </ul>
    <div id="host">
            <table class="adddeleterow table table-condensed table-no-border table-auto-width">
                <tr>
                    <th></th>' .
                    '<th>' . _('Target Host') . '</th>' .
                    '<th>' . _('Warning') . '</th>' .
                    '<th>' . _('Critical') . '</th>' .
                '</tr>';

                for ($x = 0; $x < count($serviceargs['host']); $x++) {
                    $host = encode_form_val($services['host'][$x]);
                    $warning = encode_form_val($serviceargs['host'][$x]['warning']);
                    $critical = encode_form_val($serviceargs['host'][$x]['critical']);
                    $output .= '
                    <tr>
                        <td>
                            <input type="checkbox" class="checkbox" name="services[host][' . $x . ']" ' . (isset($services['host'][$x]) ? is_checked($services['host'][$x], 1) : '') . '>
                        </td>
                        <td>
                            <select name="serviceargs[host][' . $x . '][host]" class="hostList form-control" style="width: 150px;">
                                <option value="">' . _("Host") . ': </option>';
                                    $args = array('brevity' => 1, 'orderby' => 'host_name:a');
                                    $oxml = get_xml_host_objects($args);
                                    if ($oxml) {
                                        foreach ($oxml->host as $hostobject) {
                                            $name = strval($hostobject->host_name);
                                            $output .= "<option value='" . $name . "' " . is_selected($host, $name) . ">$name</option>\n";
                                        }
                                    }
                    $output .= '
                            </select>
                        </td>
                        <td>
                            <label><img src="'.theme_image('error.png').'" class="tt-bind" title="'._('Warning Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[host][' . $x . '][warning]" value="' . $warning . '" class="form-control" />
                        </td>
                        <td>
                            <label><img src="'.theme_image('critical_small.png').'" class="tt-bind" title="'._('Critical Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[host][' . $x . '][critical]" value="' . $critical . '" class="form-control" />
                        </td>
                    </tr>';
                }
        $output .= '
        </table>
    </div> <!-- Closes #host -->

    <div id="service">
        ';
        $output .= '
            <table class="adddeleterow table table-condensed table-no-border table-auto-width">
                <tr>
                    <th></th>' .
                    '<th>' . _('Target Host') . '</th>' .
                    '<th>' . _('Target Service') . '</th>' .
                    '<th>' . _('Warning') . '</th>' .
                    '<th>' . _('Critical') . '</th>' .
                '</tr>';
            for ($x = 0; $x < count($serviceargs['service']); $x++) {
                $service = encode_form_val($services['service'][$x]);
                $host = encode_form_val($serviceargs['host'][$x]);
                $warning = encode_form_val($serviceargs['service'][$x]['warning']);
                $critical = encode_form_val($serviceargs['service'][$x]['critical']);
                $output .= '
                <tr>
                    <td>
                        <input type="checkbox" class="checkbox" name="services[service][' . $x . ']" ' . (isset($services['service'][$x]) ? is_checked($services['service'][$x], 1) : '') . '>
                    </td>
                    <td>
                        <select name="serviceargs[service][' . $x . '][host]" class="hostSList form-control" style="width: 150px;">
                            <option value="">' . _("Host") . ': </option>';
                                $args = array('brevity' => 1, 'orderby' => 'host_name:a');
                                $oxml = get_xml_host_objects($args);
                                if ($oxml) {
                                    foreach ($oxml->host as $hostobject) {
                                        $hname = strval($hostobject->host_name);
                                        $output .= "<option value='" . $hname . "' " . is_selected($host, $hname) . ">$hname</option>\n";
                                    }
                                }
                    $output .= '
                        </select>
                    </td>
                    <td>
                        <select name="serviceargs[service][' . $x . '][service]" class="serviceList form-control" style="width: 250px;">
                            <option value="">' . _("Service") . ': </option>';
                                $args = array('brevity' => 1, 'host_name' => $host, 'orderby' => 'service_description:a');
                                $oxml = get_xml_service_objects($args);
                                if ($oxml) {
                                    foreach ($oxml->service as $serviceobject) {
                                        $sname = strval($serviceobject->service_name);
                                        echo $sname;
                                        $output .= "<option value='" . $sname . "' " . is_selected($serviceargs['service'][$x]['service'], $sname) . ">$sname</option>\n";
                                    }
                                }
                    $output .= '
                        </select>
                    </td>
                    <td>
                        <label><img src="'.theme_image('error.png').'" class="tt-bind" title="'._('Warning Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[service][' . $x . '][warning]" value="' . $warning . '" class="form-control" />
                    </td>
                    <td>
                        <label><img src="'.theme_image('critical_small.png').'" class="tt-bind" title="'._('Critical Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[service][' . $x . '][critical]" value="' . $critical . '" class="form-control" />
                    </td>
                </tr>';
            }
        $output .= '
            </table>
    </div> <!-- Closes #service -->

    <div id="hostgroup">
        ';
        $output .= '
            <table class="adddeleterow table table-condensed table-no-border table-auto-width">
                <tr>
                    <th></th>' .
                    '<th>' . _('Target Hostgroup') . '</th>' .
                    '<th>' . _('Warning') . '</th>' .
                    '<th>' . _('Critical') . '</th>' .
                '</tr>';

                for ($x = 0; $x < count($serviceargs['hostgroup']); $x++) {
                    $hostgroup = encode_form_val($serviceargs['hostgroup'][$x]);
                    $warning = encode_form_val($serviceargs['hostgroup'][$x]['warning']);
                    $critical = encode_form_val($serviceargs['hostgroup'][$x]['critical']);
                    $output .= '
                    <tr>
                        <td>
                            <input type="checkbox" class="checkbox" name="services[hostgroup][' . $x . ']" ' . (isset($services['hostgroup'][$x]) ? is_checked($services['hostgroup'][$x], 1) : '') . '>
                        </td>
                        <td>
                            <select name="serviceargs[hostgroup][' . $x . '][hostgroup]" class="hostgroupList form-control" style="width: 150px;">
                            <option value="">' . _("Hostgroup") . ': </option>';
                                $args = array('orderby' => 'hostgroup_name:a');
                                $oxml = get_xml_hostgroup_objects($args);
                                if ($oxml) {
                                    foreach ($oxml->hostgroup as $hg) {
                                        $name = strval($hg->hostgroup_name);
                                        $output .= "<option value='" . $name . "' " . is_selected($hostgroup, $name) . ">$name</option>\n";
                                    }
                                }
                    $output .= '
                            </select>
                        </td>
                        <td>
                            <label><img src="'.theme_image('error.png').'" class="tt-bind" title="'._('Warning Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[hostgroup][' . $x . '][warning]" value="' . $warning . '" class="form-control" />
                        </td>
                        <td>
                            <label><img src="'.theme_image('critical_small.png').'" class="tt-bind" title="'._('Critical Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[hostgroup][' . $x . '][critical]" value="' . $critical . '" class="form-control" />
                        </td>
                    </tr>';
                }
                $output .= '
            </table>
    </div> <!-- Closes #hostgroup -->

    <div id="servicegroup">
        ';
        $output .= '
            <table class="adddeleterow table table-condensed table-no-border table-auto-width">
                <tr>
                    <th></th>' .
                    '<th>' . _('Target Servicegroup') . '</th>' .
                    '<th>' . _('Warning') . '</th>' .
                    '<th>' . _('Critical') . '</th>' .
                '</tr>';

                for ($x = 0; $x < count($serviceargs['servicegroup']); $x++) {
                    $servicegroup = encode_form_val($serviceargs['servicegroup'][$x]);
                    $warning = encode_form_val($serviceargs['servicegroup'][$x]['warning']);
                    $critical = encode_form_val($serviceargs['servicegroup'][$x]['critical']);
                    $output .= '
                    <tr>
                        <td>
                            <input type="checkbox" class="checkbox" name="services[servicegroup][' . $x . ']" ' . (isset($services['servicegroup'][$x]) ? is_checked($services['servicegroup'][$x], 1) : '') . '>
                        </td>
                        <td>
                            <select name="serviceargs[servicegroup][' . $x . '][servicegroup]" class="servicegroupList form-control" style="width: 150px;">
                                <option value="">' . _("Servicegroup") . ': </option>';
                                    $args = array('orderby' => 'servicegroup_name:a');
                                    $oxml = get_xml_servicegroup_objects($args);
                                    if ($oxml) {
                                        foreach ($oxml->servicegroup as $sg) {
                                            $name = strval($sg->servicegroup_name);
                                            $output .= "<option value='" . $name . "' " . is_selected($servicegroup, $name) . ">$name</option>\n";
                                        }
                                    }
                    $output .= '
                            </select>
                        </td>
                        <td>
                            <label><img src="'.theme_image('error.png').'" class="tt-bind" title="'._('Warning Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[servicegroup][' . $x . '][warning]" value="' . $warning . '" class="form-control" />
                        </td>
                        <td>
                            <label><img src="'.theme_image('critical_small.png').'" class="tt-bind" title="'._('Critical Threshold').'"></label>&nbsp;@&nbsp;<input type="text" size="6" name="serviceargs[servicegroup][' . $x . '][critical]" value="' . $critical . '" class="form-control" />
                        </td>
                    </tr>';
                }
                $output .= '
            </table>
    </div> <!-- Closes #servicegroup -->
</div> <!-- Closes #tabs -->

            ';

            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
        
            // get variables that were passed to us
            $address = grab_array_var($inargs, "address", "");
            $hostname = grab_array_var($inargs, "hostname");
            $username = grab_array_var($inargs, "username", "");
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $warning = grab_array_var($inargs, "warning");
            $critical = grab_array_var($inargs, "critical");

            // Use encoded data if user came back from future screen.
            $services_serial = grab_array_var($inargs, 'services_serial');
            if ($services_serial) {
                $services = unserialize(base64_decode($services_serial));
            }
            $serviceargs_serial = grab_array_var($inargs, 'serviceargs_serial');
            if ($serviceargs_serial) {
                $serviceargs = unserialize(base64_decode($serviceargs_serial));
            }

            // If no serialized data, use current request data if available.
            if (!$services)
                $services = grab_array_var($inargs, 'services');
            if (!$serviceargs)
                $serviceargs = grab_array_var($inargs, 'serviceargs');

            // check for errors
            $errors=0;
            $errmsg=array();
                
            if($errors>0){
                $outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
                $result=1;
                }
                
            break;

        case CONFIGWIZARD_MODE_GETSTAGE3OPTS:

            $output .= _('The selected SLA Report will be monitored based on the check interval.  Click Finish to continue.');
            $result = CONFIGWIZARD_HIDE_OPTIONS;

            break;

        case CONFIGWIZARD_MODE_GETSTAGE3HTML:
            
            // get variables that were passed to us
            $address = grab_array_var($inargs, "address", "");
            $hostname = grab_array_var($inargs, "hostname");
            $username = grab_array_var($inargs, "username", "");
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $warning = grab_array_var($inargs, "warning");
            $critical = grab_array_var($inargs, "critical");
            $services = grab_array_var($inargs, "services");
            $serviceargs = grab_array_var($inargs, "serviceargs");
            $services_serial = grab_array_var($inargs, "services_serial", base64_encode(serialize($services)));
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial", base64_encode(serialize($serviceargs)));

            $output='
            
                <input type="hidden" name="address" value="' . htmlentities($address) . '" />
                <input type="hidden" name="hostname" value="' . $hostname . '" />
                <input type="hidden" name="username" value="' . $username . '" />
                <input type="hidden" name="auth_file" value="' . $auth_file . '" />
                <input type="hidden" name="warning" value="' . $warning . '" />
                <input type="hidden" name="critical" value="' . $critical . '" />
                <input type="hidden" name="services_serial" value="' . $services_serial . '">
                <input type="hidden" name="serviceargs_serial" value="' . $serviceargs_serial . '">
        
                <!--SERVICES='.serialize($services).'<BR>
                SERVICEARGS='.serialize($serviceargs).'<BR>-->        
            ';
            break;
            
        case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
             
            break;
            
        case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:

            break;
            
        case CONFIGWIZARD_MODE_GETOBJECTS:
            $address = grab_array_var($inargs, "address", "");
            $hostname = grab_array_var($inargs, "hostname");
            $username = grab_array_var($inargs, "username", "");
            $auth_file = grab_array_var($inargs, "auth_file", "");
            $warning = grab_array_var($inargs, "warning");
            $critical = grab_array_var($inargs, "critical");
            $services = grab_array_var($inargs, "services", array());
            $serviceargs = grab_array_var($inargs, "serviceargs", array());
            $services_serial = grab_array_var($inargs, "services_serial", "");
            $serviceargs_serial = grab_array_var($inargs, "serviceargs_serial", "");

            $services = unserialize(base64_decode($services_serial));
            $serviceargs = unserialize(base64_decode($serviceargs_serial));

            // save data for later use in re-entrance
            $meta_arr = array();
            $meta_arr["address"] = $address;
            $meta_arr["warning"] = $warning;
            $meta_arr["critical"] = $critical;
            save_configwizard_object_meta($wizard_name, $address, "", $meta_arr);
            
            // construct service check command variable list
            $argvars = "";

            $objs = array();

            if (!host_exists($hostname)) {
                $objs[] = array(
                    "type" => OBJECTTYPE_HOST,
                    "use" => "xiwizard_generic_host",
                    "host_name" => $hostname,
                    "address" => $address,
                    "icon_image" => "sla.png",
                    "statusmap_image" => "sla.png",
                    "_xiwizard" => $wizard_name,
                    );
            }

            // see which services we should monitor
            foreach ($services as $svc => $svcstate) {

                switch ($svc) {

                    case "host":
                        foreach ($svcstate as $i => $v) {
                            // create service for each on checkbox
                            if ($v != "on")
                                continue;

                            $host = urlencode($serviceargs['host'][$i]['host']);

                            $argvars = "-H " . $address;
                            $argvars .= " -h '" . $host . "'";
                            $argvars .= " -A " . $auth_file;
                            $argvars .= " -w @" . $serviceargs['host'][$i]['warning'];
                            $argvars .= " -c @" . $serviceargs['host'][$i]['critical'];

                            $objs[] = array(
                                "type" => OBJECTTYPE_SERVICE,
                                "host_name" => $hostname,
                                "use" => "xiwizard_check_sla",
                                "service_description" => "SLA Wizard Host: " . $host,
                                "check_command" => "check_xi_sla!" . $argvars,
                                "_xiwizard" => $wizard_name,
                                );
                        }
                        break;

                    case "service":
                        foreach ($svcstate as $i => $v) {
                            // create service for each on checkbox
                            if ($v != "on")
                                continue;

                            $host = urlencode($serviceargs['service'][$i]['host']);
                            $service = urlencode($serviceargs['service'][$i]['service']);
                            $service_description = "";

                            if ($service == "") {
                                $service_description = "Service Average";
                                $service = "average";
                            } else {
                                $service_description = $service;
                            }

                            $argvars = "-H " . $address;
                            $argvars .= " -h '" . $host . "'";
                            $argvars .= " -s '" . $service . "'";
                            $argvars .= " -A " . $auth_file;
                            $argvars .= " -w @" . $serviceargs['service'][$i]['warning'];
                            $argvars .= " -c @" . $serviceargs['service'][$i]['critical'];

                            $objs[] = array(
                                "type" => OBJECTTYPE_SERVICE,
                                "host_name" => $hostname,
                                "use" => "xiwizard_check_sla",
                                "service_description" => "SLA Wizard Service: " . $service_description . " - Host: " . $host,
                                "check_command" => "check_xi_sla!" . $argvars,
                                "_xiwizard" => $wizard_name,
                                );
                        }
                        break;

                    case "hostgroup":
                        foreach ($svcstate as $i => $v) {
                            // create service for each on checkbox
                            if ($v != "on")
                                continue;

                            $hostgroup = urlencode($serviceargs['hostgroup'][$i]['hostgroup']);

                            $argvars = "-H " . $address;
                            $argvars .= " -g '" . $hostgroup . "'";
                            $argvars .= " -A " . $auth_file;
                            $argvars .= " -w @" . $serviceargs['hostgroup'][$i]['warning'];
                            $argvars .= " -c @" . $serviceargs['hostgroup'][$i]['critical'];

                            $objs[] = array(
                                "type" => OBJECTTYPE_SERVICE,
                                "host_name" => $hostname,
                                "use" => "xiwizard_check_sla",
                                "service_description" => "SLA Wizard Hostgroup: " . $hostgroup,
                                "check_command" => "check_xi_sla!" . $argvars,
                                "_xiwizard" => $wizard_name,
                                );
                        }
                        break;

                    case "servicegroup":
                        foreach ($svcstate as $i => $v) {
                            // create service for each on checkbox
                            if ($v != "on")
                                continue;

                            $servicegroup = urlencode($serviceargs['servicegroup'][$i]['servicegroup']);

                            $argvars = "-H " . $address;
                            $argvars .= " -e '" . $servicegroup . "'";
                            $argvars .= " -u " . $auth_file;
                            $argvars .= " -w @" . $serviceargs['servicegroup'][$i]['warning'];
                            $argvars .= " -c @" . $serviceargs['servicegroup'][$i]['critical'];

                            $objs[] = array(
                                "type" => OBJECTTYPE_SERVICE,
                                "host_name" => $hostname,
                                "use" => "xiwizard_check_sla",
                                "service_description" => "SLA Wizard Servicegroup: " . $servicegroup,
                                "check_command" => "check_xi_sla!" . $argvars,
                                "_xiwizard" => $wizard_name,
                                );
                        }
                        break;                        
                }
            }

            // return the object definitions to the wizard
            $outargs[CONFIGWIZARD_NAGIOS_OBJECTS] = $objs;

            break;

        default:
            break;          
        }

    return $output;
}
?>